#
# spec file for package govulncheck
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           govulncheck
Version:        1.0.4
Release:        1.2
Summary:        CLI tool to report known CVE vulnerabilities in Go source code and binaries
License:        Apache-2.0 AND BSD-3-Clause
Group:          Development/Languages/Go
URL:            https://github.com/golang/vuln
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%description
govulncheck is a CLI tool to report known vulnerabilities that affect Go code. It uses static analysis of source code or a binary's symbol table to narrow down reports to only those that could affect the application.

By default, govulncheck makes requests to the Go vulnerability database at https://vuln.go.dev. Requests to the vulnerability database contain only module paths, not code or other properties of your program. See https://vuln.go.dev/privacy.html for more. Use the -db flag to specify a different database, which must implement the specification at https://go.dev/security/vuln/database.

%prep
%autosetup -a 1

%build
go build \
   -buildmode=pie \
   ./cmd/govulncheck

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Wed Mar  6 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.0.4:
  * cmd/govulncheck: mask line numbers and columns
  * internal/scan: remove redundant new lines
  * internal/vulncheck: add position for sinks in findings' trace
  * internal/scan: put -show <option> into single quotes
  * internal/buildinfo: do module-level analysis with no PCLN table
  * internal/scan: add a newline after summary
  * internal/test: add more info on GoBuild failures
  * internal/scan: remove extra dot in a comment
  * cmd/govulncheck: fix vendor test
  * internal/vulncheck: refactor a loop with an append
  * cmd/govulncheck: fix stripped bin test
  * cmd/govulncheck: update vendor tests
  * cmd/govulncheck: add more tests and reorganize them
  * internal/vulncheck: add package and module mode for binaries
  * internal/scan: replace Source with Symbol in text output
  * internal/scan: fix error statuses for scan={package|module}
  * internal/scan: add -show verbose flag
  * internal/scan: overhaul text output
  * internal/scan: simplify redundant error checking
  * internal/scan: add scan level to testdata
  * cmd/govulncheck/integration: update expectations for stackrox
  * internal/vulncheck: support osv entries with no pkg info
  * internal/vulncheck: remove redundant symbol check
  * internal/vulncheck: simplify vulnerability detection
* Wed Mar  6 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.0.3:
  * internal/scan: add binary extract mode
  * internal/scan, vulncheck: use packages.load for mod info
  * internal/govulncheck: briefly explain streaming JSON
  * internal/vulncheck: remove -mod=mod flag from LoadModules
* Wed Jan 17 2024 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.0.2:
  * cmd/govulncheck: update test data
  * go.mod: update golang.org/x dependencies
  * internal/osv: fix type name in comment
  * internal/scan: remove informational header for package and module mode
  * internal/scan: remove redundant newline for package and module mode
  * cmd/govulncheck/integration/stackrox: update vuln expectation
  * all: update tools to pick up bug fixes
  * internal/vulncheck: compute proper db names for generic functions
  * internal/vulncheck: improve error message for fetching vulns
  * testdata: Add more package/mod level tests
  * internal/scan: change text based on scan level
  * internal/scan: update show help message
  * internal/sarif: add sarif types
  * internal/scan: enable module scan mode
  * internal/scan: add scan_level to text tests
  * internal/scan: add scan level to textHandler
  * cmd/govulncheck: rearrange test files
  * all: add logging to TestGovulncheck
  * internal/scan: disallow package input in mod level
  * go.mod: update golang.org/x dependencies
  * cmd/govulncheck: fix mod level behavior
  * all: update to x/tools@v.15.0
  * internal/vulncheck: define Binary over Bin
  * internal/vulncheck: add binary abstraction data structure
  * cmd/govulncheck: organize tests into subdirs
  * internal/scan: Improve "Informational" text output
  * internal/scan: properly "genericify" choose
  * internal/vulncheck: emit package findings all at once
  * internal/vulncheck: update logic for package level analysis
  * internal/vulncheck: remove obsolete tests and helpers
  * internal/scan: remove obsolete function
  * internal/scan: check for go mod before running
  * cmd/govulncheck/integration: add new expectations
  * cmd/govulncheck: Fix no go mod tests
  * internal/vulncheck: rename moduleVulnerabilities
  * internal/vulncheck: add documentation and propagate errors
  * internal/vulncheck: emit OSVs in their raw form asap
  * internal/scan: move emit logic for findings to internal/vulncheck
  * internal: properly fetch modules in source mode
  * internal/scan: verify scan level flag
  * internal/govulncheck: update Finding docstring
  * internal/vulncheck: remove file set computation
  * internal/scan: generate better message when patterns matches no packages
  * internal/scan, vulncheck: emit vulns as found
  * internal/scan: use modVersion for mod version
  * internal/scan: suggest earliest valid fixed version as the fix
  * internal/scan: communicate default value for test flag
  * internal/semver: rename the LatestFixedVersion function
  * cmd/govulncheck: fix incorrect test file name
  * cmd/govulncheck: remove go version for test file
  * internal/vulnchec: improve comments and names for imports level logic
  * internal/govulncheck: update description of Findings
  * internal/vulncheck/internal/buildinfo: support stripped darwin binaries
  * internal/scan: update test names
  * internal/scan: text output allows module level vulns
  * internal/client: add additional context to HTTP error message
  * internal/scan: add isImported function
  * internal/scan: fix trace count bug
  * internal/vulncheck: add LoadModules using go.mod
  * internal/govulncheck: add WantPackages scan level
* Sun Sep 24 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.0.1:
  * all: go get golang.org/x/tools@74c255b
  * internal/scan: change the way convert mode works
  * internal/scan: add -version flag
  * internal/vulncheck/internal/gosym: fix typo
  * internal/gosym: update binary mode version parsing
  * internal/scan: refactor to remove redundant code
  * vulncheck/internal/gosym: add support for go versions > 1.20
  * internal/vulncheck/internal/buildinfo: skip failing tests
  * cmd/govulncheck: skip TestCommand in short mode
- _service add setversion to automatically update spec Version
* Tue Sep 12 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of license based on legaldb scan
  Add Apache 2.0 for google/go-cmdtest and
  vendor/github.com/google/renameio
* Tue Jul 18 2023 jkowalczyk@suse.com
- Initial package version 1.0.0:
  * internal/scan: print the summary even when there are no findings
  * cmd,internal/govulncheck: change protocol version to v1.0.0
  * cmd,internal: remove experimental reference
  * internal/govulncheck: improve documentation
